# Fini

L'expérience s'est terminée avec succès.

- L'heure : `%(time)s`
- Journal : `%(logfile)s`

Vous pouvez :

[Ouvrir le journal](opensesame://event.after_experiment_open_logfile){: .button}

[Ouvrir le dossier du journal](opensesame://event.after_experiment_open_logfile_folder){: .button}

[Copier le journal dans le groupe de fichiers](opensesame://event.after_experiment_copy_logfile){: .button}
